@@ -17,15 +17,21 @@
 package commons
 
 import (
+	"encoding/json"
+	"fmt"
+	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
 
 	"github.com/accurics/terrascan/pkg/downloader"
 	"github.com/accurics/terrascan/pkg/iac-providers/output"
+	"github.com/accurics/terrascan/pkg/iac-providers/terraform/commons/test"
 	"github.com/accurics/terrascan/pkg/utils"
+	"github.com/hashicorp/go-multierror"
 	"github.com/hashicorp/hcl/v2"
 	hclConfigs "github.com/hashicorp/terraform/configs"
+	"github.com/spf13/afero"
 	"go.uber.org/zap"
 )
 
@@ -40,6 +46,10 @@ var (
 		SourceAddr: testLocalSourceAddr,
 		CallRange:  hcl.Range{Filename: testFileNamePath},
 	}
+
+	invalidDirErrStringTemplate = "directory '%s' has no terraform config files"
+	testDataDir                 = "testdata"
+	tfJSONDir                   = filepath.Join(testDataDir, "tfjson")
 )
 
 func TestProcessLocalSource(t *testing.T) {
@@ -324,3 +334,69 @@ func TestGetRemoteModuleIfPresentInTerraformSrc(t *testing.T) {
 		})
 	}
 }
+
+func TestTerraformDirectoryLoaderLoadIacDir(t *testing.T) {
+	var nilMultiErr *multierror.Error = nil
+	tests := []struct {
+		name        string
+		tfConfigDir string
+		tfJSONFile  string
+		options     map[string]interface{}
+		wantErr     error
+	}{
+		{
+			name:        "directory with resources having container defined",
+			tfConfigDir: filepath.Join(testDataDir, "terraform-container-extraction"),
+			tfJSONFile:  filepath.Join(tfJSONDir, "output-with-containers.json"),
+			wantErr: multierror.Append(
+				fmt.Errorf(invalidDirErrStringTemplate, filepath.Join(testDataDir, "terraform-container-extraction")),
+				fmt.Errorf(invalidDirErrStringTemplate, filepath.Join(testDataDir, "terraform-container-extraction/terraform-aws-provider/task-definitions")),
+			),
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			tr := TerraformDirectoryLoader{
+				absRootDir:               tt.tfConfigDir,
+				remoteDownloader:         downloader.NewRemoteDownloader(),
+				parser:                   hclConfigs.NewParser(afero.NewOsFs()),
+				terraformInitModuleCache: make(map[string]TerraformModuleManifest),
+			}
+			got, gotErr := tr.LoadIacDir()
+			me, ok := gotErr.(*multierror.Error)
+			if !ok {
+				t.Errorf("expected multierror.Error, got %T", gotErr)
+			}
+			if tt.wantErr == nilMultiErr {
+				if err := me.ErrorOrNil(); err != nil {
+					t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
+				}
+			} else if me.Error() != tt.wantErr.Error() {
+				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
+			}
+
+			var want output.AllResourceConfigs
+
+			// Read the expected value and unmarshal into want
+			contents, _ := ioutil.ReadFile(tt.tfJSONFile)
+			if utils.IsWindowsPlatform() {
+				contents = utils.ReplaceWinNewLineBytes(contents)
+			}
+
+			err := json.Unmarshal(contents, &want)
+			if err != nil {
+				t.Errorf("unexpected error unmarshalling want: %v", err)
+			}
+
+			match, err := test.IdenticalAllResourceConfigs(got, want)
+			if err != nil {
+				t.Errorf("unexpected error checking result: %v", err)
+			}
+			if !match {
+				g, _ := json.MarshalIndent(got, "", "  ")
+				w, _ := json.MarshalIndent(want, "", "  ")
+				t.Errorf("got '%v', want: '%v'", string(g), string(w))
+			}
+		})
+	}
+}
